@@ -2,7 +2,6 @@ from qutip import *
 import numpy as np
 import matplotlib.pyplot as plt
 
-
 class System:
     """
     The system class defines the physical system through a model hamiltonian.
@@ -26,7 +25,7 @@ class System:
     current_states = None
 
     def __init__(self, n=None, H=None, rho=None, a=None, u=None, c_ops=None, e_ops=None, tlist=None, diagonalize=False):
-        self.n = n if n is not None else 2  # Note: number of energy levels = maximum excited state + 1 = n+1
+        self.n = n if n is not None else 3  # Note: number of energy levels = maximum excited state + 1 = n+1
         self.rho = rho if rho is not None else fock_dm(self.n+1, 0)  # starting density matrix. Default is ground state
         self.a = a if a is not None else destroy(self.n+1)  # lowering operator
         self.u = u if u is not None else self.a.dag()+self.a  # dipole operator
@@ -132,7 +131,7 @@ class System:
             # evolving after pulse interaction in case the delay is non-zero
             delta_t = time_delays[i]
             if delta_t > 0:
-                coherence_time = np.linspace(0, delta_t, delta_t*r)
+                coherence_time = np.linspace(0, delta_t, int(delta_t*r))
                 results = mesolve(self.H, rho, coherence_time, self.c_ops, [])
                 rho = results.states[-1]  # keeping only the last state
 
@@ -140,7 +139,7 @@ class System:
         # now applying the pulse and the delay that has to be scanned --> therefore saving all states.
         rho = self.apply_pulse(rho, diagram[scan_id[0]])
         delta_t = time_delays[scan_id[0]]
-        t_list = np.linspace(0, delta_t, delta_t * r)
+        t_list = np.linspace(0, delta_t, int(delta_t*r))
         results = mesolve(self. H, rho, t_list, self.c_ops, [])
         states = results.states
 
@@ -149,18 +148,22 @@ class System:
             states = [self.apply_pulse(state, diagram[i]) for state in states]  # applying interaction to all states
             delta_t = time_delays[i]
             if delta_t > 0:
-                coherence_time = np.linspace(0, delta_t, delta_t*r)
+                coherence_time = np.linspace(0, delta_t, int(delta_t*r))
                 # evolving each state in the list states and storing only the last state
                 if parallel:
                     self.tlist = coherence_time
                     states = pp.parallel_map(self.para_mesolve, states, only_last_state=True)
+                    #states = [pp.parfor(self.para_mesolve, states, only_last_state=True)]
+                    #print('shape of states is ', np.shape(states))
                 else:
                     states = [mesolve(self.H, state, coherence_time, self.c_ops, []).states[-1] for state in states]
 
         # Now at this point only last interaction and last scan-able delay is left.
+        print('First scan done, starting second scan. Remaining time = First Scan Time x number of steps in second scan'
+              + '/number of processors')
         states = [self.apply_pulse(state, diagram[scan_id[1]]) for state in states]
         delta_t = time_delays[scan_id[1]]
-        t_list = np.linspace(0, delta_t, delta_t*r)
+        t_list = np.linspace(0, delta_t, int(delta_t*r))
         final_states = []
         if parallel:
             self.tlist = t_list
@@ -170,13 +173,13 @@ class System:
             final_states = [mesolve(self.H, state, t_list, self.c_ops, []).states for state in states]
 
         dipole = np.array([expect(self.u, final_states[x][:]) for x in range(len(final_states))])
-
+        #dipole = None
         #plt.figure()
         #plt.imshow(dipole.imag, origin='lower', interpolation='spline36', extent=[0, time_delays[scan_id[0]],
         #                                                                          0, time_delays[scan_id[1]]])
         #plt.show()
-
-        return final_states, np.linspace(0, time_delays[scan_id[0]], time_delays[scan_id[0]] * r), t_list, dipole
+        print('second scan done')
+        return final_states, np.linspace(0, time_delays[scan_id[0]], int(time_delays[scan_id[0]] * r)), t_list, dipole
 
     # some small helper functions to keep the coherence2D function readable
     def apply_pulse(self, rho, x):
